import { select, 
        json,
        csv,
        tsv, 
        geoPath,
        geoMercator,
        scaleOrdinal,
        schemeCategory10,
        zoom,
        event } from 'd3';
import { feature } from 'topojson';

const svg = select('svg');
const width = parseFloat(svg.attr('width'));
const height = +svg.attr('height');
let stateNames = [];

const projection = geoMercator()
			.clipExtent([[0,0],[width,height]])
			.center([78.9, 20.6])
			.scale(770);

const pathGenerator = geoPath()
		.projection(projection);

const g = svg.append('g');

svg.call(zoom().on('zoom', () => {
	g.attr('transform', event.transform)
}));

//https://raw.githubusercontent.com/deldersveld/topojson/master/countries/india/india-districts.json
//https://raw.githubusercontent.com/deldersveld/topojson/master/countries/india/india-states.json

Promise.all([json('https://gist.githubusercontent.com/Gogineni44/795f105c3d32ce7bb36b9386c975b2ac/raw/5a8528587438bf546cb1c7f3d07a4ca9375f52f9/Australia.csv'),
             json('https://gist.githubusercontent.com/Gogineni44/795f105c3d32ce7bb36b9386c975b2ac/raw/5a8528587438bf546cb1c7f3d07a4ca9375f52f9/Australia.csv')
            ]).then(([stateJSON, districtJSON]) => {
	 
  const districtGroup = g.append('g')
  const stateGroup = g.append('g');
  
  const districts = feature(districtJSON, districtJSON.objects['india-districts-2019-734']);			
  const states = feature(stateJSON, stateJSON.objects.IND_adm1);
  
  const colorScale = scaleOrdinal(schemeCategory10);
  
  const districtPath = districtGroup.selectAll('path')
    .data(districts.features)
  districtPath.enter().append('path')
    .attr("class", "districts")
    .attr('d', d => pathGenerator(d))
  	.style('fill', d => colorScale(d.properties.st_nm))
  .append('title')
    .text(d => {
    return `${d.properties.district}, \n${d.properties.st_nm}`;
  	});
  
  const statePath = stateGroup.selectAll('path')
    .data(states.features)
  statePath.enter().append('path')
    .attr('class', 'states')
    .attr('d', d => pathGenerator(d))
});
      